Special Functions
-----------------

.. toctree::
    :caption: Special functions
    :maxdepth: 4

.. :py:module:: pygsl.testing.sf

Airy Functions
~~~~~~~~~~~~~~
     .. include:: sf/sf__airy_doc.rst

Bessel Functions
~~~~~~~~~~~~~~~~
    .. include:: sf/sf__bessel_doc.rst

Clausen Functions
~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__clausen_doc.rst

Coulomb Functions
~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__coulomb_doc.rst

Coupling Functions
~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__coupling_doc.rst

Dawson Function
~~~~~~~~~~~~~~~
    .. include:: sf/sf__dawson_doc.rst

Debye Functions
~~~~~~~~~~~~~~~
    .. include:: sf/sf__debye_doc.rst

Dilogarithm
~~~~~~~~~~~
    .. include:: sf/sf__dilog_doc.rst

Elementary Operations
~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__elementary_doc.rst

Ellipitcal Integrals
~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__ellint_doc.rst
    .. include:: sf/sf__elljac_doc.rst

Error Functions
~~~~~~~~~~~~~~~
    .. include:: sf/sf__erf_doc.rst

Exponential Functions and Integrals
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    .. include:: sf/sf__exp_doc.rst


Fermi Dirac Functions
~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__fermi_dirac_doc.rst

Gamma and Beta Functions
~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__gamma_doc.rst
    .. include:: sf/sf__poch_doc.rst


Gegenbauer Functions
~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__gegenpoly_doc.rst

Hermite Polynomials and Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__hermite_doc.rst

Hypergeometric Functions
~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__hyperg_doc.rst

Laguerre Functions
~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__laguerre_doc.rst

Lambert Functions
~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__lambert_doc.rst

Legendre Functions and Spherical Harmonics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__legendre_doc.rst

Logarithm and related functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__log_doc.rst

Mathieu functions
~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__mathieu_doc.rst

Power functions
~~~~~~~~~~~~~~~
    .. include:: sf/sf__pow_doc.rst

Psi functions
~~~~~~~~~~~~~
    .. include:: sf/sf__psi_doc.rst

Synchrotron functions
~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__synchrotron_doc.rst

Transport Functions
~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__transport_doc.rst

Trigonometric Functions
~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__trig_doc.rst

Zeta Functions
~~~~~~~~~~~~~~
    .. include:: sf/sf__zeta_doc.rst

Complex implementations of standard functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__gsl_complex_doc.rst

Unsorted functions
~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__misc_doc.rst



Hydrogenic functions
~~~~~~~~~~~~~~~~~~~~
    .. include:: sf/sf__hydrogenic_doc.rst

